changeset 11038:f93c3156e05a

(frame-initialize): Set frame-creation-function to `make-terminal-frame' if appropriate.
author Karl Heuer <kwzh@gnu.org>
date Thu, 16 Mar 1995 20:23:22 +0000
parents 802a774b44b7
children c9e2537da847
files lisp/frame.el
diffstat 1 files changed, 8 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/frame.el	Thu Mar 16 18:51:49 1995 +0000
+++ b/lisp/frame.el	Thu Mar 16 20:23:22 1995 +0000
@@ -187,12 +187,15 @@
 	(delete-frame terminal-frame)
 	(setq terminal-frame nil))
 
     ;; No, we're not running a window system.  Arrange to cause errors.
     (setq frame-creation-function
-	  (function
-	   (lambda (parameters)
-	     (error
-	      "Can't create multiple frames without a window system"))))))
+	  (if (fboundp 'make-terminal-frame)
+	      'make-terminal-frame
+	    (function
+	     (lambda (parameters)
+	       (error
+		"Can't create multiple frames without a window system")))))))
 
 ;;; startup.el calls this function after loading the user's init
 ;;; file.  Now default-frame-alist and initial-frame-alist contain
@@ -187,12 +187,15 @@
 	(setq terminal-frame nil))
 
-    ;; No, we're not running a window system.  Arrange to cause errors.
+    ;; No, we're not running a window system.  Use make-terminal-frame if
+    ;; we support that feature, otherwise arrange to cause errors.
     (setq frame-creation-function